@@ -17,7 +17,7 @@ our @ISA = qw(Math::BigInt);
 our @EXPORT_OK = qw/objectify/;
 my $class = 'Math::BigInt::Lite';
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 ##############################################################################
 # global constants, flags and accessory
@@ -267,8 +267,8 @@ sub config {
         my $param = shift;
 
         # We don't use a math backend library.
-        return undef if ($param eq 'lib' ||
-                         $param eq 'lib_version');
+        return if ($param eq 'lib' ||
+                   $param eq 'lib_version');
 
         return $class -> SUPER::config($param);
     }
@@ -1253,6 +1253,12 @@ sub bsqrt {
     $x;
 }
 
+sub bpi {
+    my $self = shift;
+    my $class = ref($self) || $self;
+    $class -> new("3");
+}
+
 sub to_bin {
     my $self  = shift;
     $upgrade -> new($$self) -> to_bin();
